<?php
/**
 * Gutenify University: Block Patterns
 *
 * @since Gutenify University 1.0
 */

 /**
  * Get patterns content.
  *
  * @param string $file_name Filename.
  * @return string
  */
function gutenify_university_get_pattern_content( $file_name ) {
	ob_start();
	include get_theme_file_path( '/inc/patterns/' . $file_name . '.php' );
	$output = ob_get_contents();
	ob_end_clean();
	return $output;
}

/**
 * Registers block patterns and categories.
 *
 * @since Gutenify University 1.0
 *
 * @return void
 */
function gutenify_university_register_block_patterns() {

	$patterns = array(
		'footer-default' => array(
			'title'      => __( 'Default footer', 'gutenify-university' ),
			'categories' => array( 'gutenify-university-footers' ),
			'blockTypes' => array( 'core/template-part/footer' ),
		),
		'header-default' => array(
			'title'      => __( 'Default header', 'gutenify-university' ),
			'categories' => array( 'gutenify-university-headers' ),
			'blockTypes' => array( 'core/template-part/header' ),
		),
		'post-listing' => array(
			'title'    => __( 'Post Listing', 'gutenify-university' ),
			'inserter' => false,
			'categories' => array( 'gutenify-university-query' ),
		),
		'hidden-404' => array(
			'title'    => __( '404 content', 'gutenify-university' ),
			'categories' => array( 'gutenify-university-pages' ),
		),
		'page-cover-title' => array(
			'title'    => __( 'Page Cover Title', 'gutenify-university' ),
			'categories' => array( 'featured' ),
		),
	);

	$block_pattern_categories = array(
		'featured'                 => array( 'label' => __( 'Featured', 'gutenify-university' ) ),
		'gutenify-university-footers' => array( 'label' => __( 'Footers', 'gutenify-university' ) ),
		'gutenify-university-headers' => array( 'label' => __( 'Headers', 'gutenify-university' ) ),
		'gutenify-university-query'   => array( 'label' => __( 'Query', 'gutenify-university' ) ),
		'gutenify-university-pages'   => array( 'label' => __( 'Pages', 'gutenify-university' ) ),
	);

	/**
	 * Filters the theme block pattern categories.
	 *
	 * @since Gutenify University 1.0
	 *
	 * @param array[] $block_pattern_categories {
	 *     An associative array of block pattern categories, keyed by category name.
	 *
	 *     @type array[] $properties {
	 *         An array of block category properties.
	 *
	 *         @type string $label A human-readable label for the pattern category.
	 *     }
	 * }
	 */
	$block_pattern_categories = apply_filters( 'gutenify_university_block_pattern_categories', $block_pattern_categories );

	foreach ( $block_pattern_categories as $name => $properties ) {
		if ( ! WP_Block_Pattern_Categories_Registry::get_instance()->is_registered( $name ) ) {
			register_block_pattern_category( $name, $properties );
		}
	}

	$block_patterns = array(
		'hidden-404',
		'post-listing',
		'footer-default',
		'header-default',
		'page-cover-title',
	);

	/**
	 * Filters the theme block patterns.
	 *
	 * @since Gutenify University 1.0
	 *
	 * @param array $block_patterns List of block patterns by name.
	 */
	$block_patterns = apply_filters( 'gutenify_university_block_patterns', $block_patterns );

	foreach ( $block_patterns as $block_pattern ) {
		// $pattern_file = get_theme_file_path( '/inc/patterns/' . $block_pattern . '.php' );
		$pattern = $patterns[ $block_pattern ];
		$pattern['content'] = gutenify_university_get_pattern_content( $block_pattern );
		register_block_pattern(
			'gutenify-university/' . $block_pattern,
			$pattern
		);
	}
}
add_action( 'init', 'gutenify_university_register_block_patterns', 9 );
